==> esp8266-0.3.0.crate: esp8266-0.3.0/src/slc/slc_intvec_tohost.rs <==
#[doc = "Register `SLC_INTVEC_TOHOST` reader"]
pub struct R(crate::R<SLC_INTVEC_TOHOST_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<SLC_INTVEC_TOHOST_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::convert::From<crate::R<SLC_INTVEC_TOHOST_SPEC>> for R {
    fn from(reader: crate::R<SLC_INTVEC_TOHOST_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `SLC_INTVEC_TOHOST` writer"]
pub struct W(crate::W<SLC_INTVEC_TOHOST_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<SLC_INTVEC_TOHOST_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl core::convert::From<crate::W<SLC_INTVEC_TOHOST_SPEC>> for W {
    fn from(writer: crate::W<SLC_INTVEC_TOHOST_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `SLC_TOHOST_INTVEC` reader - "]
pub struct SLC_TOHOST_INTVEC_R(crate::FieldReader<u8, u8>);
impl SLC_TOHOST_INTVEC_R {
    pub(crate) fn new(bits: u8) -> Self {
        SLC_TOHOST_INTVEC_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for SLC_TOHOST_INTVEC_R {
    type Target = crate::FieldReader<u8, u8>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `SLC_TOHOST_INTVEC` writer - "]
pub struct SLC_TOHOST_INTVEC_W<'a> {
    w: &'a mut W,
}
impl<'a> SLC_TOHOST_INTVEC_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub unsafe fn bits(self, value: u8) -> &'a mut W {
        self.w.bits = (self.w.bits & !0xff) | ((value as u32) & 0xff);
        self.w
    }
}
impl R {
    #[doc = "Bits 0:7"]
    #[inline(always)]
    pub fn slc_tohost_intvec(&self) -> SLC_TOHOST_INTVEC_R {
        SLC_TOHOST_INTVEC_R::new((self.bits & 0xff) as u8)
    }
}
impl W {
    #[doc = "Bits 0:7"]
    #[inline(always)]
    pub fn slc_tohost_intvec(&mut self) -> SLC_TOHOST_INTVEC_W {
        SLC_TOHOST_INTVEC_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "SLC_INTVEC_TOHOST\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [slc_intvec_tohost](index.html) module"]
pub struct SLC_INTVEC_TOHOST_SPEC;
impl crate::RegisterSpec for SLC_INTVEC_TOHOST_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [slc_intvec_tohost::R](R) reader structure"]
impl crate::Readable for SLC_INTVEC_TOHOST_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [slc_intvec_tohost::W](W) writer structure"]
impl crate::Writable for SLC_INTVEC_TOHOST_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets SLC_INTVEC_TOHOST to value 0"]
impl crate::Resettable for SLC_INTVEC_TOHOST_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}

==> esp8266-0.4.0.crate: esp8266-0.4.0/src/slc/slc_intvec_tohost.rs <==
#[doc = "Register `SLC_INTVEC_TOHOST` reader"]
pub struct R(crate::R<SLC_INTVEC_TOHOST_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<SLC_INTVEC_TOHOST_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<SLC_INTVEC_TOHOST_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<SLC_INTVEC_TOHOST_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `SLC_INTVEC_TOHOST` writer"]
pub struct W(crate::W<SLC_INTVEC_TOHOST_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<SLC_INTVEC_TOHOST_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl From<crate::W<SLC_INTVEC_TOHOST_SPEC>> for W {
    #[inline(always)]
    fn from(writer: crate::W<SLC_INTVEC_TOHOST_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `SLC_TOHOST_INTVEC` reader - "]
pub struct SLC_TOHOST_INTVEC_R(crate::FieldReader<u8, u8>);
impl SLC_TOHOST_INTVEC_R {
    #[inline(always)]
    pub(crate) fn new(bits: u8) -> Self {
        SLC_TOHOST_INTVEC_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for SLC_TOHOST_INTVEC_R {
    type Target = crate::FieldReader<u8, u8>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `SLC_TOHOST_INTVEC` writer - "]
pub struct SLC_TOHOST_INTVEC_W<'a> {
    w: &'a mut W,
}
impl<'a> SLC_TOHOST_INTVEC_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub unsafe fn bits(self, value: u8) -> &'a mut W {
        self.w.bits = (self.w.bits & !0xff) | (value as u32 & 0xff);
        self.w
    }
}
impl R {
    #[doc = "Bits 0:7"]
    #[inline(always)]
    pub fn slc_tohost_intvec(&self) -> SLC_TOHOST_INTVEC_R {
        SLC_TOHOST_INTVEC_R::new((self.bits & 0xff) as u8)
    }
}
impl W {
    #[doc = "Bits 0:7"]
    #[inline(always)]
    pub fn slc_tohost_intvec(&mut self) -> SLC_TOHOST_INTVEC_W {
        SLC_TOHOST_INTVEC_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    #[inline(always)]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "SLC_INTVEC_TOHOST\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [slc_intvec_tohost](index.html) module"]
pub struct SLC_INTVEC_TOHOST_SPEC;
impl crate::RegisterSpec for SLC_INTVEC_TOHOST_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [slc_intvec_tohost::R](R) reader structure"]
impl crate::Readable for SLC_INTVEC_TOHOST_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [slc_intvec_tohost::W](W) writer structure"]
impl crate::Writable for SLC_INTVEC_TOHOST_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets SLC_INTVEC_TOHOST to value 0"]
impl crate::Resettable for SLC_INTVEC_TOHOST_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}
